@@ -1,4 +1,4 @@
-use crate::types::{Collection, NodePool};
+use crate::types::{Cluster, Collection, NodePool};
 use eyre::eyre;
 
 mod types;
@@ -60,14 +60,14 @@ impl RancherClient {
     }
 
     pub async fn node_pools(&self) -> eyre::Result<Collection<NodePool>> {
-        let nodepools = self
+        let response = self
             .http
             .get(self.base_url.join("v3/nodepools").unwrap())
             .bearer_auth(&self.bearer_token)
             .send()
             .await?;
 
-        let bytes = nodepools.bytes().await?;
+        let bytes = response.bytes().await?;
         let string = String::from_utf8(bytes.to_vec())?;
 
         let collection: Collection<NodePool> = serde_json::from_str(&string)?;
@@ -75,6 +75,22 @@ impl RancherClient {
         Ok(collection)
     }
 
+    pub async fn clusters(&self) -> eyre::Result<Collection<Cluster>> {
+        let response = self
+            .http
+            .get(self.base_url.join("v3/clusters").unwrap())
+            .bearer_auth(&self.bearer_token)
+            .send()
+            .await?;
+
+        let bytes = response.bytes().await?;
+        let string = String::from_utf8(bytes.to_vec())?;
+
+        let collection: Collection<Cluster> = serde_json::from_str(&string)?;
+
+        Ok(collection)
+    }
+
     pub async fn set_drain_before_delete(
         &self,
         cluster_id: &str,
@@ -132,6 +148,13 @@ mod test {
         rc.node_pools().await.unwrap();
     }
 
+    #[tokio::test]
+    async fn test_get_clusters() {
+        let rc = RancherClient::from_config_file("https://console.aws.dockyard.viasat.io").unwrap();
+
+        rc.clusters().await.unwrap();
+    }
+
     #[tokio::test]
     async fn test_update_node_pool() {
         let rc = RancherClient::new(
